#!/usr/bin/env bash

set -e
old_version="$(git describe --abbrev=0 --tags)"
new_version=$1
# new_version="0.11.0"

# make sure new version parameter is passed
if [ -z "$1" ]
    then
        echo "ERROR - pass new version. usage release.sh 0.11.0"
        exit 2
fi

# make sure changle log updated
while true; do
    read -p "Did you update CHANGELOG.md? " yn
    case $yn in
        [Yy]* ) break;;
        [Nn]* ) exit;;
        * ) echo "Please answer yes or no.";;
    esac
done

echo "build, lint and test"
npm start build lint test

echo "commit change log updates"
git commit -am "update CHANGELOG with new version"

echo "npm version $1 --no-git-tag-version"
npm version $1 --no-git-tag-version

echo "create new git tag"
git tag $1

echo "generate documentation"
npm start api

echo "archive documentation"
zip -r konva-v${new_version}.zip ./api/*
rm -r ./api

echo "documentation is generated"
echo "include konva-v${new_version}-documentation.zip into version in github"

echo "copy konva.js into konva-site"
cp ./konva.js ../konva-site/
cd ../konva-site

echo "replace CDN links"
old_cdn="https://cdn.rawgit.com/konvajs/konva/${old_version}/konva.min.js"
new_cdn="https://cdn.rawgit.com/konvajs/konva/${new_version}/konva.min.js"
find source themes -exec perl -i -pe "s|${old_cdn}|${new_cdn}|g" {} +

echo "regenerate site"
npm start

echo "commit site changes"
git add .

DATE=`date +%Y-%m-%d`
git commit -am "update ${DATE}" --allow-empty
git push

echo "clean previous generated site"
cd ../konvajs.github.io
rm -r ./*

echo "copy new generated files"
cp -r ../konva-site/public/* ./
git status

echo "commit and push site changes"
git add .
git commit -am "update ${DATE}"
git push

cd ../konva
git commit -am "version ${new_version}"
git push
git push --tags
npm publish

echo "DONE!"
